@@ -10,11 +10,6 @@
 #' @export
 #' @examples
 #' \dontrun{
-#' rnet <- overline(routes_fast[c(2, 3, 22), ], attrib = "length")
-#' plot(rnet)
-#' lines(routes_fast[22, ], col = "red") # line without overlaps
-#' islines(routes_fast[2, ], routes_fast[3, ])
-#' islines(routes_fast[2, ], routes_fast[22, ])
 #' # sf implementation
 #' islines(routes_fast_sf[2, ], routes_fast_sf[3, ])
 #' islines(routes_fast_sf[2, ], routes_fast_sf[22, ])
@@ -22,10 +17,6 @@
 islines <- function(g1, g2) {
   UseMethod("islines")
 }
-islines.Spatial <- function(g1, g2) {
-  ## return TRUE if geometries intersect as lines, not points
-  inherits(rgeos::gIntersection(g1, g2), "SpatialLines")
-}
 islines.sf <- function(g1, g2) {
   sf::st_geometry_type(sf::st_intersection(sf::st_geometry(g1), sf::st_geometry(g2))) == "MULTILINESTRING"
 }
@@ -54,28 +45,11 @@ islines.sf <- function(g1, g2) {
 #'   rsec <- gsection(sl, buff_dist = 50)
 #'   length(rsec) # 4 features: issue
 #'   plot(rsec, col = seq(length(rsec)))
-#'   # dont test due to issues with sp classes on some set-ups
-#'   # sl <- routes_fast[2:4, ]
-#'   # rsec <- gsection(sl)
-#'   # rsec_buff <- gsection(sl, buff_dist = 1)
-#'   # plot(sl[1], lwd = 9, col = 1:nrow(sl))
-#'   # plot(rsec, col = 5 + (1:length(rsec)), add = TRUE, lwd = 3)
-#'   # plot(rsec_buff, col = 5 + (1:length(rsec_buff)), add = TRUE, lwd = 3)
 #' }
 gsection <- function(sl, buff_dist = 0) {
   UseMethod("gsection")
 }
 #' @export
-gsection.Spatial <- function(sl, buff_dist = 0) {
-  if (buff_dist > 0) {
-    sl <- geo_toptail(sl, toptail_dist = buff_dist)
-  }
-  overlapping <- rgeos::gOverlaps(sl, byid = T)
-  u <- rgeos::gUnion(sl, sl)
-  u_merged <- rgeos::gLineMerge(u)
-  sp::disaggregate(u_merged)
-}
-#' @export
 gsection.sf <- function(sl, buff_dist = 0) {
   if (buff_dist > 0) {
     sl <- geo_toptail(sl, toptail_dist = buff_dist)
@@ -87,24 +61,6 @@ gsection.sf <- function(sl, buff_dist = 0) {
 
   u_disag
 }
-#' Label SpatialLinesDataFrame objects
-#'
-#' This function adds labels to lines plotted using base graphics. Largely
-#' for illustrative purposes, not designed for publication-quality
-#' graphics.
-#'
-#' @param sl A SpatialLinesDataFrame with overlapping elements
-#' @param attrib A text string corresponding to a named variable in `sl`
-#'
-#' @author Barry Rowlingson
-#' @family rnet
-#'
-#' @export
-lineLabels <- function(sl, attrib) {
-  text(sp::coordinates(
-    rgeos::gCentroid(sl, byid = TRUE)
-  ), labels = sl[[attrib]])
-}
 
 #' Convert series of overlapping lines into a route network
 #'
@@ -173,7 +129,7 @@ lineLabels <- function(sl, attrib) {
 #' @export
 #' @examples
 #' sl <- routes_fast_sf[2:4, ]
-#' sl$All <- flowlines$All[2:4]
+#' sl$All <- flowlines_sf$All[2:4]
 #' rnet <- overline(sl = sl, attrib = "All")
 #' nrow(sl)
 #' nrow(rnet)
@@ -186,12 +142,6 @@ lineLabels <- function(sl, attrib) {
 #' plot(rnet_sf_raw)
 #' rnet_sf_raw$n <- 1:nrow(rnet_sf_raw)
 #' plot(rnet_sf_raw[10:25, ])
-#' # legacy implementation based on sp data
-#' # sl <- routes_fast[2:4, ]
-#' # rnet1 <- overline(sl = sl, attrib = "length")
-#' # rnet2 <- overline(sl = sl, attrib = "length", buff_dist = 1)
-#' # plot(rnet1, lwd = rnet1$length / mean(rnet1$length))
-#' # plot(rnet2, lwd = rnet2$length / mean(rnet2$length))
 overline <- function(sl,
                      attrib,
                      ncores = 1,
@@ -408,73 +358,7 @@ overline2 <-
   }
 #' @export
 overline.sf <- overline2
-#' @export
-overline.Spatial <- function(sl, ...) {
-  overline_spatial(sl, ...)
-}
 
-#' Spatial aggregation of routes represented with sp classes
-#'
-#' This function, largely superseded by sf implementations, still works
-#' but is not particularly fast.
-#'
-#' @param na.zero Sets whether aggregated values with a value of zero are
-#'   removed.
-#' @inheritParams gsection
-#' @inheritParams overline
-#' @family rnet
-#' @export
-overline_spatial <- function(sl, attrib, fun = sum, na.zero = FALSE, buff_dist = 0) {
-  fun <- c(fun)
-  if (length(fun) < length(attrib)) {
-    fun <- rep(c(fun), length.out = length(attrib))
-  }
-
-  sl_sp <- as(sl, "SpatialLines")
-
-  ## get the line sections that make the network
-  slu <- gsection(sl, buff_dist = buff_dist)
-  ## overlay network with routes
-  overs <- sp::over(slu, sl_sp, returnList = TRUE)
-  ## overlay is true if end points overlay, so filter them out:
-  overs <- lapply(1:length(overs), function(islu) {
-    Filter(function(isl) {
-      islines(sl_sp[isl, ], slu[islu, ])
-    }, overs[[islu]])
-  })
-  ## now aggregate the required attribibute using fun():
-  # aggs = sapply(overs, function(os){fun(sl[[attrib]][os])})
-  aggs <- setNames(
-    as.data.frame(
-      lapply(
-        1:length(attrib),
-        function(y, overs, attribs, aggfuns) {
-          sapply(overs, function(os, attrib, fun2) {
-            fun2(sl[[attrib]][os])
-          },
-          attrib = attribs[y],
-          fun2 = aggfuns[[y]]
-          )
-        },
-        overs,
-        attrib,
-        fun
-      )
-    ),
-    attrib
-  )
-
-  ## make a sl with the named attribibute:
-  sl <- sp::SpatialLinesDataFrame(slu, aggs)
-  # names(sl) = attrib
-
-  ## remove lines with attribute values of zero
-  if (na.zero) {
-    sl <- sl[sl[[attrib]] > 0, ]
-  }
-
-  sl
-}
 
 #' Aggregate flows so they become non-directional (by geometry - the slow way)
 #'
@@ -484,9 +368,6 @@ overline_spatial <- function(sl, attrib, fun = sum, na.zero = FALSE, buff_dist =
 #' If only the largest flow in either direction is captured in an analysis, for
 #' example, the true extent of travel will by heavily under-estimated for
 #' OD pairs which have similar amounts of travel in both directions.
-#' Flows in both direction are often represented by overlapping lines with
-#' identical geometries (see [flowlines()]) which can be confusing
-#' for users and are difficult to plot.
 #'
 #' This function aggregates directional flows into non-directional flows,
 #' potentially halving the number of lines objects and reducing the number
@@ -501,20 +382,6 @@ overline_spatial <- function(sl, attrib, fun = sum, na.zero = FALSE, buff_dist =
 #' with a distance (i.e. not intra-zone flows) are included
 #' @family lines
 #' @export
-#' @examples
-#' plot(flowlines[1:30, ], lwd = flowlines$On.foot[1:30])
-#' singlines <- onewaygeo(flowlines[1:30, ], attrib = which(names(flowlines) == "On.foot"))
-#' plot(singlines, lwd = singlines$On.foot / 2, col = "red", add = TRUE)
-#' \dontrun{
-#' plot(flowlines, lwd = flowlines$All / 10)
-#' singlelines <- onewaygeo(flowlines, attrib = 3:14)
-#' plot(singlelines, lwd = singlelines$All / 20, col = "red", add = TRUE)
-#' sum(singlelines$All) == sum(flowlines$All)
-#' nrow(singlelines)
-#' singlelines_sf <- onewaygeo(flowlines_sf, attrib = 3:14)
-#' sum(singlelines_sf$All) == sum(flowlines_sf$All)
-#' summary(singlelines$All == singlelines_sf$All)
-#' }
 onewaygeo <- function(x, attrib) {
   UseMethod("onewaygeo")
 }
@@ -528,33 +395,6 @@ onewaygeo.sf <- function(x, attrib) {
 
   return(singlelines)
 }
-#' @export
-onewaygeo.Spatial <- function(x, attrib) {
-  geq <- rgeos::gEquals(x, x, byid = TRUE) | rgeos::gEqualsExact(x, x, byid = TRUE)
-  sel1 <- !duplicated(geq) # repeated rows
-  singlelines <- x[sel1, ]
-  non_numeric_cols <- which(!sapply(x@data, is.numeric))
-  keeper_cols <- sort(unique(c(non_numeric_cols, attrib)))
-
-  singlelines@data[, attrib] <- (matrix(
-    unlist(
-      lapply(
-        apply(geq, 1, function(x) {
-          which(x == TRUE)
-        }),
-        function(y, x) {
-          colSums(x[y, attrib]@data)
-        }, x
-      )
-    ),
-    nrow = nrow(x),
-    byrow = TRUE
-  ))[sel1, ]
-
-  singlelines@data <- singlelines@data[keeper_cols]
-
-  return(singlelines)
-}
 
 #' Convert series of overlapping lines into a route network
 #'
@@ -564,7 +404,6 @@ onewaygeo.Spatial <- function(x, attrib) {
 #'
 #' @param sl An `sf` `LINESTRING` object with overlapping elements
 #' @inheritParams overline
-#' @inheritParams overline_spatial
 #' @export
 #' @examples
 #' routes_fast_sf$value <- 1
